import { useContext } from '@antv/gi-sdk';
import { Table } from 'antd';
import React from 'react';
import { ITEM_STATE } from './registerMeta';
import $i18n from '../i18n';
var ResultTable = function ResultTable(_ref) {
  var _ref$matches = _ref.matches,
    matches = _ref$matches === void 0 ? [] : _ref$matches;
  var _useContext = useContext(),
    graph = _useContext.graph;
  var getResultColumns = function getResultColumns() {
    var columns = [{
      title: $i18n.get({
        id: 'gi-assets-algorithm.src.PatternMatch.resultTable.SerialNumber',
        dm: '序号'
      }),
      dataIndex: 'index',
      key: 'index',
      width: 60
    }, {
      title: $i18n.get({
        id: 'gi-assets-algorithm.src.PatternMatch.resultTable.NumberOfNodes',
        dm: '节点数量'
      }),
      dataIndex: 'nodeNum',
      key: 'nodeNum'
    }, {
      title: $i18n.get({
        id: 'gi-assets-algorithm.src.PatternMatch.resultTable.NumberOfEdges',
        dm: '边数量'
      }),
      dataIndex: 'edgeNum',
      key: 'edgeNum'
    }];
    return columns;
  };
  var getResultTableData = function getResultTableData() {
    return matches.map(function (match, i) {
      var _a, _b;
      return {
        key: "".concat(i),
        index: i + 1,
        nodeNum: ((_a = match.nodes) === null || _a === void 0 ? void 0 : _a.length) || 0,
        edgeNum: ((_b = match.edges) === null || _b === void 0 ? void 0 : _b.length) || 0
      };
    });
  };
  var clearActiveItems = function clearActiveItems() {
    var activateItems = graph.findAllByState('node', ITEM_STATE.Active).concat(graph.findAllByState('edge', ITEM_STATE.Active));
    activateItems.forEach(function (item) {
      graph.setItemState(item, ITEM_STATE.Active, false);
    });
  };
  var onEnterTableRow = function onEnterTableRow(record) {
    var _a, _b, _c, _d;
    clearActiveItems();
    (_b = (_a = matches[record.index - 1]) === null || _a === void 0 ? void 0 : _a.nodes) === null || _b === void 0 ? void 0 : _b.forEach(function (node) {
      graph.setItemState(node.id, ITEM_STATE.Active, true);
    });
    (_d = (_c = matches[record.index - 1]) === null || _c === void 0 ? void 0 : _c.edges) === null || _d === void 0 ? void 0 : _d.forEach(function (edge) {
      graph.setItemState(edge.id, ITEM_STATE.Active, true);
    });
  };
  return /*#__PURE__*/React.createElement("div", {
    className: "kg-pattern-match-result-wrapper"
  }, /*#__PURE__*/React.createElement("p", {
    className: "kg-pattern-match-result-title"
  }, $i18n.get({
    id: 'gi-assets-algorithm.src.PatternMatch.resultTable.PatternMatchingResultList',
    dm: '模式匹配结果列表'
  })), /*#__PURE__*/React.createElement(Table, {
    dataSource: getResultTableData(),
    columns: getResultColumns(),
    size: "small",
    style: {
      marginTop: '16px'
    },
    showSorterTooltip: {
      title: $i18n.get({
        id: 'gi-assets-algorithm.src.PatternMatch.resultTable.Sort',
        dm: '排序'
      })
    },
    onRow: function onRow(record) {
      return {
        onMouseEnter: function onMouseEnter() {
          return onEnterTableRow(record);
        },
        onMouseLeave: clearActiveItems
      };
    }
  }));
};
export default ResultTable;