"use strict";

function _typeof(obj) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (obj) { return typeof obj; } : function (obj) { return obj && "function" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }, _typeof(obj); }
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _g2plot = require("@antv/g2plot");
var _graphin = require("@antv/graphin");
var _lodash = require("lodash");
var _react = _interopRequireWildcard(require("react"));
var _registerMeta = require("./registerMeta");
var _i18n = _interopRequireDefault(require("../i18n"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
var plot = null;
var dataTypeLocaleMap = {};
var ResultTable = function ResultTable(_ref) {
  var data = _ref.data,
    currentAlgo = _ref.currentAlgo,
    edgeType = _ref.edgeType;
  var _useContext = (0, _react.useContext)(_graphin.GraphinContext),
    graph = _useContext.graph;
  var plotRef = (0, _react.useRef)(null);
  (0, _react.useEffect)(function () {
    var plotData = getPlotData();
    if (plot) {
      plot.destroy();
    }
    //@ts-ignore
    plot = new _g2plot.Column(plotRef.current, {
      data: plotData,
      xField: 'value',
      yField: 'count',
      maxColumnWidth: 60,
      colorField: 'count',
      legend: {
        layout: 'horizontal',
        position: 'bottom',
        offsetY: 4,
        maxRow: 2
      },
      label: {
        position: 'middle',
        style: {
          fill: '#FFFFFF',
          opacity: 0.6
        }
      },
      xAxis: {
        title: {
          text: _i18n.default.get({
            id: 'gi-assets-algorithm.src.NodeImportance.resultPlot.ImportanceValue',
            dm: '重要性值'
          }),
          position: 'end',
          offset: 14,
          style: {
            stroke: '#fff',
            lineWidth: 2,
            fontWeight: 400
          }
        }
      },
      yAxis: {
        title: {
          text: _i18n.default.get({
            id: 'gi-assets-algorithm.src.NodeImportance.resultPlot.NumberOfNodes',
            dm: '节点数量'
          }),
          position: 'end',
          autoRotate: false,
          spacing: -55,
          style: {
            stroke: '#fff',
            lineWidth: 2,
            fontWeight: 400
          }
        }
      }
    });
    plot.render();
    plot.on('interval:mouseleave', clearActiveItems);
    plot.on('interval:mouseenter', onEnterColumn);
  }, [data]);
  var getPlotData = function getPlotData() {
    var _a;
    var plotData = [];
    var countMap = (0, _lodash.groupBy)(((_a = data.node) === null || _a === void 0 ? void 0 : _a.data) || [], 'value');
    Object.keys(countMap).forEach(function (key) {
      plotData.push({
        //@ts-ignore
        value: key,
        //@ts-ignore
        count: countMap[key].length
      });
    });
    return plotData;
  };
  var clearActiveItems = function clearActiveItems() {
    var activateItems = graph.findAllByState('node', _registerMeta.ITEM_STATE.Active).concat(graph.findAllByState('edge', _registerMeta.ITEM_STATE.Active));
    activateItems.forEach(function (item) {
      graph.setItemState(item, _registerMeta.ITEM_STATE.Active, false);
    });
  };
  var onEnterColumn = function onEnterColumn(e) {
    var _a, _b, _c, _d, _e;
    if (!((_a = e.data) === null || _a === void 0 ? void 0 : _a.data)) {
      return;
    }
    var value = (_c = (_b = e.data) === null || _b === void 0 ? void 0 : _b.data) === null || _c === void 0 ? void 0 : _c.value;
    clearActiveItems();
    var nodes = data.node.data.filter(function (node) {
      return +node.value === +value;
    });
    var nodeIds = nodes.map(function (node) {
      return node.id;
    });
    nodes.forEach(function (node) {
      var item = graph.findById(node.id);
      if (item) {
        graph.setItemState(item, _registerMeta.ITEM_STATE.Active, true);
      }
    });
    // 若未关系属性重要性, 同时高亮该节点相关的被映射过的边
    if (currentAlgo === 'edge-property') {
      (_e = (_d = data.edge) === null || _d === void 0 ? void 0 : _d.data) === null || _e === void 0 ? void 0 : _e.forEach(function (edge) {
        var edgeItem = graph.findById(edge.id);
        if (!edgeItem) {
          return;
        }
        var edgeModel = edgeItem.getModel();
        if (nodeIds.includes(edgeModel.source) || nodeIds.includes(edgeModel.target)) {
          graph.setItemState(edgeItem, _registerMeta.ITEM_STATE.Active, true);
        }
      });
    }
  };
  return /*#__PURE__*/_react.default.createElement("div", null, /*#__PURE__*/_react.default.createElement("div", {
    className: "plot-wrapper",
    ref: plotRef
  }));
};
var _default = ResultTable;
exports.default = _default;